@@ -1,31 +1,13 @@
-# Before `make install' is performed this script should be runnable with
-# `make test'. After `make install' it should work as `perl test.pl'
-
-#########################
-
-# change 'tests => 1' to 'tests => last_test_to_print';
-
+#!/usr/local/bin/perl -w
+use strict;
+use lib '../../'; # TESTING
+use FileHandle::Rollback;
+use Fcntl ':flock';
 use Test;
 
-
 BEGIN { plan tests => 12 };
 
 
-# TESTING
-use lib '../../';
-
-use FileHandle::Rollback;
-use strict;
-use Fcntl ':flock';
-
-
-#########################
-
-# Insert your test code below, the Test module is use()ed here so read
-# its man page ( perldoc Test ) for help writing this test script.
-
-
-
 # path for test file
 my $path = './test.db';
 my $org = '0123456789';
